@@ -15,6 +15,10 @@ __all__ = [
     'datasource_pagination_api',
     'event',
     'ingest_api',
+    'ingest_workflow_api',
+    'module',
+    'modules_api',
+    'persistent_compute_api',
     'scout',
     'scout_api',
     'scout_asset_api',
@@ -29,7 +33,6 @@ __all__ = [
     'scout_comparisonrun_api',
     'scout_compute_api',
     'scout_compute_api_deprecated',
-    'scout_compute_representation_api',
     'scout_compute_resolved_api',
     'scout_dataexport_api',
     'scout_datareview_api',
@@ -72,7 +75,7 @@ __all__ = [
     'upload_api',
 ]
 
-__conjure_generator_version__ = "4.9.0"
+__conjure_generator_version__ = "4.17.0"
 
-__version__ = "0.586.1"
+__version__ = "0.757.0"
 
