@@ -1,6 +1,7 @@
 # coding=utf-8
 from .._impl import (
     scout_compute_api_AbsoluteThreshold as AbsoluteThreshold,
+    scout_compute_api_AbsoluteTimestampSeries as AbsoluteTimestampSeries,
     scout_compute_api_AfterPersistenceWindow as AfterPersistenceWindow,
     scout_compute_api_AggregateEnumSeries as AggregateEnumSeries,
     scout_compute_api_AggregateNumericSeries as AggregateNumericSeries,
@@ -8,6 +9,10 @@ from .._impl import (
     scout_compute_api_ApproximateThresholdOperator as ApproximateThresholdOperator,
     scout_compute_api_ApproximateThresholdRanges as ApproximateThresholdRanges,
     scout_compute_api_ArithmeticSeries as ArithmeticSeries,
+    scout_compute_api_ArrowBucketedEnumPlot as ArrowBucketedEnumPlot,
+    scout_compute_api_ArrowBucketedNumericPlot as ArrowBucketedNumericPlot,
+    scout_compute_api_ArrowEnumPlot as ArrowEnumPlot,
+    scout_compute_api_ArrowNumericPlot as ArrowNumericPlot,
     scout_compute_api_AssetChannel as AssetChannel,
     scout_compute_api_Average as Average,
     scout_compute_api_BandPassConfiguration as BandPassConfiguration,
@@ -23,6 +28,8 @@ from .._impl import (
     scout_compute_api_BitOperationFunctionVisitor as BitOperationFunctionVisitor,
     scout_compute_api_BitOperationSeries as BitOperationSeries,
     scout_compute_api_BitOrFunction as BitOrFunction,
+    scout_compute_api_BitShiftLeftFunction as BitShiftLeftFunction,
+    scout_compute_api_BitShiftRightFunction as BitShiftRightFunction,
     scout_compute_api_BitTestFunction as BitTestFunction,
     scout_compute_api_BitXorFunction as BitXorFunction,
     scout_compute_api_BucketedCartesian3dPlot as BucketedCartesian3dPlot,
@@ -66,6 +73,16 @@ from .._impl import (
     scout_compute_api_Context as Context,
     scout_compute_api_Count as Count,
     scout_compute_api_CumulativeSumSeries as CumulativeSumSeries,
+    scout_compute_api_CurveFit as CurveFit,
+    scout_compute_api_CurveFitDetails as CurveFitDetails,
+    scout_compute_api_CurveFitDetailsVisitor as CurveFitDetailsVisitor,
+    scout_compute_api_CurveFitOptions as CurveFitOptions,
+    scout_compute_api_CurveFitPlotType as CurveFitPlotType,
+    scout_compute_api_CurveFitPlotTypeVisitor as CurveFitPlotTypeVisitor,
+    scout_compute_api_CurveFitResult as CurveFitResult,
+    scout_compute_api_CurveResultDetails as CurveResultDetails,
+    scout_compute_api_CurveResultDetailsVisitor as CurveResultDetailsVisitor,
+    scout_compute_api_DataSourceAndChannel as DataSourceAndChannel,
     scout_compute_api_DataSourceChannel as DataSourceChannel,
     scout_compute_api_DecimateStrategy as DecimateStrategy,
     scout_compute_api_DecimateStrategyVisitor as DecimateStrategyVisitor,
@@ -77,6 +94,9 @@ from .._impl import (
     scout_compute_api_DriverSeries3d as DriverSeries3d,
     scout_compute_api_DurationConstant as DurationConstant,
     scout_compute_api_DurationConstantVisitor as DurationConstantVisitor,
+    scout_compute_api_DurationFilterRanges as DurationFilterRanges,
+    scout_compute_api_Enum1dArraySeries as Enum1dArraySeries,
+    scout_compute_api_Enum1dArraySeriesVisitor as Enum1dArraySeriesVisitor,
     scout_compute_api_EnumAggregationFunction as EnumAggregationFunction,
     scout_compute_api_EnumBucket as EnumBucket,
     scout_compute_api_EnumCountDuplicateSeries as EnumCountDuplicateSeries,
@@ -91,7 +111,6 @@ from .._impl import (
     scout_compute_api_EnumResampleSeries as EnumResampleSeries,
     scout_compute_api_EnumSeries as EnumSeries,
     scout_compute_api_EnumSeriesEqualityRanges as EnumSeriesEqualityRanges,
-    scout_compute_api_EnumSeriesFunction as EnumSeriesFunction,
     scout_compute_api_EnumSeriesVisitor as EnumSeriesVisitor,
     scout_compute_api_EnumTimeRangeFilterSeries as EnumTimeRangeFilterSeries,
     scout_compute_api_EnumTimeShiftSeries as EnumTimeShiftSeries,
@@ -101,7 +120,10 @@ from .._impl import (
     scout_compute_api_ErrorCode as ErrorCode,
     scout_compute_api_ErrorResult as ErrorResult,
     scout_compute_api_ErrorType as ErrorType,
+    scout_compute_api_EventsSearchRanges as EventsSearchRanges,
     scout_compute_api_ExcludeNegativeValues as ExcludeNegativeValues,
+    scout_compute_api_ExponentialCurve as ExponentialCurve,
+    scout_compute_api_ExponentialResultDetails as ExponentialResultDetails,
     scout_compute_api_Fft as Fft,
     scout_compute_api_FirstPointMatchingCondition as FirstPointMatchingCondition,
     scout_compute_api_ForwardFillInterpolation as ForwardFillInterpolation,
@@ -110,8 +132,6 @@ from .._impl import (
     scout_compute_api_FrequencyDomainPlot as FrequencyDomainPlot,
     scout_compute_api_FrequencyDomainVisitor as FrequencyDomainVisitor,
     scout_compute_api_FunctionReference as FunctionReference,
-    scout_compute_api_FunctionVariable as FunctionVariable,
-    scout_compute_api_FunctionVariableVisitor as FunctionVariableVisitor,
     scout_compute_api_FunctionVariables as FunctionVariables,
     scout_compute_api_GeoPoint as GeoPoint,
     scout_compute_api_GeoPointVisitor as GeoPointVisitor,
@@ -122,6 +142,10 @@ from .._impl import (
     scout_compute_api_GeoSummaryStrategyVisitor as GeoSummaryStrategyVisitor,
     scout_compute_api_GeoTemporalSummary as GeoTemporalSummary,
     scout_compute_api_GeoTimeBucket as GeoTimeBucket,
+    scout_compute_api_GroupedComputeNodeResponse as GroupedComputeNodeResponse,
+    scout_compute_api_GroupedComputeNodeResponses as GroupedComputeNodeResponses,
+    scout_compute_api_Grouping as Grouping,
+    scout_compute_api_GroupingVisitor as GroupingVisitor,
     scout_compute_api_HighPassConfiguration as HighPassConfiguration,
     scout_compute_api_Histogram as Histogram,
     scout_compute_api_HistogramChannelCount as HistogramChannelCount,
@@ -136,6 +160,8 @@ from .._impl import (
     scout_compute_api_LatLongBounds as LatLongBounds,
     scout_compute_api_LatLongGeo as LatLongGeo,
     scout_compute_api_LatLongPoint as LatLongPoint,
+    scout_compute_api_LiteralRange as LiteralRange,
+    scout_compute_api_LiteralRanges as LiteralRanges,
     scout_compute_api_LocalVariableName as LocalVariableName,
     scout_compute_api_LogExactMatchCaseInsensitiveFilter as LogExactMatchCaseInsensitiveFilter,
     scout_compute_api_LogFilterOperator as LogFilterOperator,
@@ -149,6 +175,8 @@ from .._impl import (
     scout_compute_api_LogUnionOperation as LogUnionOperation,
     scout_compute_api_LogUnionSeries as LogUnionSeries,
     scout_compute_api_LogValue as LogValue,
+    scout_compute_api_LogarithmicCurve as LogarithmicCurve,
+    scout_compute_api_LogarithmicResultDetails as LogarithmicResultDetails,
     scout_compute_api_LowPassConfiguration as LowPassConfiguration,
     scout_compute_api_MaxSeries as MaxSeries,
     scout_compute_api_Maximum as Maximum,
@@ -160,6 +188,8 @@ from .._impl import (
     scout_compute_api_NegativeValueConfiguration as NegativeValueConfiguration,
     scout_compute_api_NegativeValueConfigurationVisitor as NegativeValueConfigurationVisitor,
     scout_compute_api_NotRanges as NotRanges,
+    scout_compute_api_Numeric1dArraySeries as Numeric1dArraySeries,
+    scout_compute_api_Numeric1dArraySeriesVisitor as Numeric1dArraySeriesVisitor,
     scout_compute_api_NumericAggregationFunction as NumericAggregationFunction,
     scout_compute_api_NumericApproximateFilterSeries as NumericApproximateFilterSeries,
     scout_compute_api_NumericBucket as NumericBucket,
@@ -174,7 +204,6 @@ from .._impl import (
     scout_compute_api_NumericPoint as NumericPoint,
     scout_compute_api_NumericResampleSeries as NumericResampleSeries,
     scout_compute_api_NumericSeries as NumericSeries,
-    scout_compute_api_NumericSeriesFunction as NumericSeriesFunction,
     scout_compute_api_NumericSeriesVisitor as NumericSeriesVisitor,
     scout_compute_api_NumericThresholdFilterSeries as NumericThresholdFilterSeries,
     scout_compute_api_NumericTimeRangeFilterSeries as NumericTimeRangeFilterSeries,
@@ -183,6 +212,7 @@ from .._impl import (
     scout_compute_api_NumericUnionSeries as NumericUnionSeries,
     scout_compute_api_OffsetSeries as OffsetSeries,
     scout_compute_api_OnChangeRanges as OnChangeRanges,
+    scout_compute_api_OutputFormat as OutputFormat,
     scout_compute_api_OutputRangeStart as OutputRangeStart,
     scout_compute_api_OutputRangeStartVisitor as OutputRangeStartVisitor,
     scout_compute_api_PageInfo as PageInfo,
@@ -199,17 +229,22 @@ from .._impl import (
     scout_compute_api_PeakType as PeakType,
     scout_compute_api_PercentageThreshold as PercentageThreshold,
     scout_compute_api_PersistenceWindowConfiguration as PersistenceWindowConfiguration,
+    scout_compute_api_Point3d as Point3d,
+    scout_compute_api_PolynomialCurve as PolynomialCurve,
+    scout_compute_api_PolynomialResultDetails as PolynomialResultDetails,
+    scout_compute_api_PowerCurve as PowerCurve,
+    scout_compute_api_PowerResultDetails as PowerResultDetails,
     scout_compute_api_ProductSeries as ProductSeries,
     scout_compute_api_Range as Range,
     scout_compute_api_RangeAggregation as RangeAggregation,
     scout_compute_api_RangeAggregationOperation as RangeAggregationOperation,
     scout_compute_api_RangeAggregationOperationVisitor as RangeAggregationOperationVisitor,
+    scout_compute_api_RangeMap as RangeMap,
     scout_compute_api_RangeSeries as RangeSeries,
     scout_compute_api_RangeSeriesVisitor as RangeSeriesVisitor,
     scout_compute_api_RangeSummary as RangeSummary,
     scout_compute_api_RangeValue as RangeValue,
     scout_compute_api_RangeValueVisitor as RangeValueVisitor,
-    scout_compute_api_RangesFunction as RangesFunction,
     scout_compute_api_RangesNumericAggregation as RangesNumericAggregation,
     scout_compute_api_RangesSummary as RangesSummary,
     scout_compute_api_Reference as Reference,
@@ -223,8 +258,12 @@ from .._impl import (
     scout_compute_api_ScaleSeries as ScaleSeries,
     scout_compute_api_Scatter as Scatter,
     scout_compute_api_Scatter3d as Scatter3d,
+    scout_compute_api_ScatterCurveFit as ScatterCurveFit,
+    scout_compute_api_ScatterFitOptions as ScatterFitOptions,
     scout_compute_api_ScatterSummarizationStrategy as ScatterSummarizationStrategy,
     scout_compute_api_ScatterSummarizationStrategyVisitor as ScatterSummarizationStrategyVisitor,
+    scout_compute_api_SelectIndexFrom1dEnumArraySeries as SelectIndexFrom1dEnumArraySeries,
+    scout_compute_api_SelectIndexFrom1dNumericArraySeries as SelectIndexFrom1dNumericArraySeries,
     scout_compute_api_SelectValue as SelectValue,
     scout_compute_api_SelectValueVisitor as SelectValueVisitor,
     scout_compute_api_Series as Series,
@@ -255,12 +294,19 @@ from .._impl import (
     scout_compute_api_SummarizeGeo as SummarizeGeo,
     scout_compute_api_SummarizeRanges as SummarizeRanges,
     scout_compute_api_SummarizeSeries as SummarizeSeries,
+    scout_compute_api_TagFilter as TagFilter,
+    scout_compute_api_TagFilterOperator as TagFilterOperator,
+    scout_compute_api_TagFilterValidationErrorType as TagFilterValidationErrorType,
+    scout_compute_api_TagFilters as TagFilters,
+    scout_compute_api_TagFiltersVisitor as TagFiltersVisitor,
     scout_compute_api_Threshold as Threshold,
     scout_compute_api_ThresholdOperator as ThresholdOperator,
     scout_compute_api_ThresholdVisitor as ThresholdVisitor,
     scout_compute_api_ThresholdingRanges as ThresholdingRanges,
     scout_compute_api_TimeBucketedGeoPlot as TimeBucketedGeoPlot,
     scout_compute_api_TimeDifferenceSeries as TimeDifferenceSeries,
+    scout_compute_api_TimeSeriesCurveFit as TimeSeriesCurveFit,
+    scout_compute_api_TimeSeriesFitOptions as TimeSeriesFitOptions,
     scout_compute_api_TimestampAndId as TimestampAndId,
     scout_compute_api_TimestampConstant as TimestampConstant,
     scout_compute_api_TimestampConstantVisitor as TimestampConstantVisitor,
@@ -275,6 +321,7 @@ from .._impl import (
     scout_compute_api_UnitResultVisitor as UnitResultVisitor,
     scout_compute_api_UnitsMissing as UnitsMissing,
     scout_compute_api_ValueDifferenceSeries as ValueDifferenceSeries,
+    scout_compute_api_ValueMapSeries as ValueMapSeries,
     scout_compute_api_VariableName as VariableName,
     scout_compute_api_VariableValue as VariableValue,
     scout_compute_api_VariableValueVisitor as VariableValueVisitor,
@@ -282,3 +329,333 @@ from .._impl import (
     scout_compute_api_WindowVisitor as WindowVisitor,
 )
 
+__all__ = [
+    'AbsoluteThreshold',
+    'AbsoluteTimestampSeries',
+    'AfterPersistenceWindow',
+    'AggregateEnumSeries',
+    'AggregateNumericSeries',
+    'AllowNegativeValues',
+    'ApproximateThresholdOperator',
+    'ApproximateThresholdRanges',
+    'ArithmeticSeries',
+    'ArrowBucketedEnumPlot',
+    'ArrowBucketedNumericPlot',
+    'ArrowEnumPlot',
+    'ArrowNumericPlot',
+    'AssetChannel',
+    'Average',
+    'BandPassConfiguration',
+    'BandStopConfiguration',
+    'BatchComputeUnitResult',
+    'BatchComputeUnitsRequest',
+    'BatchComputeWithUnitsRequest',
+    'BatchComputeWithUnitsResponse',
+    'BinaryArithmeticOperation',
+    'BinaryArithmeticSeries',
+    'BitAndFunction',
+    'BitOperationFunction',
+    'BitOperationFunctionVisitor',
+    'BitOperationSeries',
+    'BitOrFunction',
+    'BitShiftLeftFunction',
+    'BitShiftRightFunction',
+    'BitTestFunction',
+    'BitXorFunction',
+    'BucketedCartesian3dPlot',
+    'BucketedCartesianPlot',
+    'BucketedEnumPlot',
+    'BucketedGeoPlot',
+    'BucketedGeoPlotVisitor',
+    'BucketedNumericPlot',
+    'Cartesian',
+    'CartesianVisitor',
+    'Cartesian3d',
+    'Cartesian3dVisitor',
+    'Cartesian3dBounds',
+    'Cartesian3dBucket',
+    'Cartesian3dUnitResult',
+    'CartesianBounds',
+    'CartesianBucket',
+    'CartesianPlot',
+    'CartesianUnitResult',
+    'ChannelSeries',
+    'ChannelSeriesVisitor',
+    'CompactEnumPoint',
+    'ComputableNode',
+    'ComputableNodeVisitor',
+    'ComputeNode',
+    'ComputeNodeVisitor',
+    'ComputeNodeFromReferenceRequest',
+    'ComputeNodeRequest',
+    'ComputeNodeResponse',
+    'ComputeNodeResponseVisitor',
+    'ComputeNodeResult',
+    'ComputeNodeResultVisitor',
+    'ComputeNodeWithContext',
+    'ComputeUnitResult',
+    'ComputeUnitResultVisitor',
+    'ComputeUnitsRequest',
+    'ComputeWithUnitsRequest',
+    'ComputeWithUnitsResponse',
+    'ComputeWithUnitsResult',
+    'Context',
+    'Count',
+    'CumulativeSumSeries',
+    'CurveFit',
+    'CurveFitDetails',
+    'CurveFitDetailsVisitor',
+    'CurveFitOptions',
+    'CurveFitPlotType',
+    'CurveFitPlotTypeVisitor',
+    'CurveFitResult',
+    'CurveResultDetails',
+    'CurveResultDetailsVisitor',
+    'DataSourceAndChannel',
+    'DataSourceChannel',
+    'DecimateStrategy',
+    'DecimateStrategyVisitor',
+    'DecimateWithBuckets',
+    'DecimateWithResolution',
+    'DerivativeSeries',
+    'DoubleConstant',
+    'DoubleConstantVisitor',
+    'DriverSeries3d',
+    'DurationConstant',
+    'DurationConstantVisitor',
+    'DurationFilterRanges',
+    'Enum1dArraySeries',
+    'Enum1dArraySeriesVisitor',
+    'EnumAggregationFunction',
+    'EnumBucket',
+    'EnumCountDuplicateSeries',
+    'EnumFilterOperator',
+    'EnumFilterRanges',
+    'EnumFilterTransformationSeries',
+    'EnumHistogramBucket',
+    'EnumHistogramNode',
+    'EnumHistogramPlot',
+    'EnumPlot',
+    'EnumPoint',
+    'EnumResampleSeries',
+    'EnumSeries',
+    'EnumSeriesVisitor',
+    'EnumSeriesEqualityRanges',
+    'EnumTimeRangeFilterSeries',
+    'EnumTimeShiftSeries',
+    'EnumUnionOperation',
+    'EnumUnionSeries',
+    'EqualityOperator',
+    'ErrorCode',
+    'ErrorResult',
+    'ErrorType',
+    'EventsSearchRanges',
+    'ExcludeNegativeValues',
+    'ExponentialCurve',
+    'ExponentialResultDetails',
+    'Fft',
+    'FirstPointMatchingCondition',
+    'ForwardFillInterpolation',
+    'ForwardFillResampleInterpolationConfiguration',
+    'FrequencyDomain',
+    'FrequencyDomainVisitor',
+    'FrequencyDomainPlot',
+    'FunctionReference',
+    'FunctionVariables',
+    'GeoPoint',
+    'GeoPointVisitor',
+    'GeoPointWithTimestamp',
+    'GeoSeries',
+    'GeoSeriesVisitor',
+    'GeoSummaryStrategy',
+    'GeoSummaryStrategyVisitor',
+    'GeoTemporalSummary',
+    'GeoTimeBucket',
+    'GroupedComputeNodeResponse',
+    'GroupedComputeNodeResponses',
+    'Grouping',
+    'GroupingVisitor',
+    'HighPassConfiguration',
+    'Histogram',
+    'HistogramVisitor',
+    'HistogramChannelCount',
+    'IncompatibleUnitOperation',
+    'IntegerConstant',
+    'IntegerConstantVisitor',
+    'IntegralSeries',
+    'InterpolationConfiguration',
+    'InterpolationConfigurationVisitor',
+    'IntersectRanges',
+    'LatLongBounds',
+    'LatLongGeo',
+    'LatLongPoint',
+    'LiteralRange',
+    'LiteralRanges',
+    'LocalVariableName',
+    'LogExactMatchCaseInsensitiveFilter',
+    'LogFilterOperator',
+    'LogFilterOperatorVisitor',
+    'LogFilterSeries',
+    'LogPoint',
+    'LogRegexFilterOperator',
+    'LogSeries',
+    'LogSeriesVisitor',
+    'LogTimeShiftSeries',
+    'LogUnionOperation',
+    'LogUnionSeries',
+    'LogValue',
+    'LogarithmicCurve',
+    'LogarithmicResultDetails',
+    'LowPassConfiguration',
+    'MaxSeries',
+    'Maximum',
+    'MeanSeries',
+    'MinMaxThresholdOperator',
+    'MinMaxThresholdRanges',
+    'MinSeries',
+    'Minimum',
+    'NegativeValueConfiguration',
+    'NegativeValueConfigurationVisitor',
+    'NotRanges',
+    'Numeric1dArraySeries',
+    'Numeric1dArraySeriesVisitor',
+    'NumericAggregationFunction',
+    'NumericApproximateFilterSeries',
+    'NumericBucket',
+    'NumericFilterTransformationSeries',
+    'NumericHistogramBucket',
+    'NumericHistogramBucketStrategy',
+    'NumericHistogramBucketStrategyVisitor',
+    'NumericHistogramBucketWidthAndOffset',
+    'NumericHistogramNode',
+    'NumericHistogramPlot',
+    'NumericPlot',
+    'NumericPoint',
+    'NumericResampleSeries',
+    'NumericSeries',
+    'NumericSeriesVisitor',
+    'NumericThresholdFilterSeries',
+    'NumericTimeRangeFilterSeries',
+    'NumericTimeShiftSeries',
+    'NumericUnionOperation',
+    'NumericUnionSeries',
+    'OffsetSeries',
+    'OnChangeRanges',
+    'OutputFormat',
+    'OutputRangeStart',
+    'OutputRangeStartVisitor',
+    'PageInfo',
+    'PageStrategy',
+    'PageStrategyVisitor',
+    'PageToken',
+    'PageTokenVisitor',
+    'PagedLogPlot',
+    'ParameterInput',
+    'ParameterizedComputeNodeRequest',
+    'ParameterizedComputeNodeResponse',
+    'ParameterizedContext',
+    'PeakRanges',
+    'PeakType',
+    'PercentageThreshold',
+    'PersistenceWindowConfiguration',
+    'Point3d',
+    'PolynomialCurve',
+    'PolynomialResultDetails',
+    'PowerCurve',
+    'PowerResultDetails',
+    'ProductSeries',
+    'Range',
+    'RangeAggregation',
+    'RangeAggregationOperation',
+    'RangeAggregationOperationVisitor',
+    'RangeMap',
+    'RangeSeries',
+    'RangeSeriesVisitor',
+    'RangeSummary',
+    'RangeValue',
+    'RangeValueVisitor',
+    'RangesNumericAggregation',
+    'RangesSummary',
+    'Reference',
+    'ResampleConfiguration',
+    'ResampleInterpolationConfiguration',
+    'ResampleInterpolationConfigurationVisitor',
+    'RollingOperationSeries',
+    'RollingOperator',
+    'RollingOperatorVisitor',
+    'RunChannel',
+    'ScaleSeries',
+    'Scatter',
+    'Scatter3d',
+    'ScatterCurveFit',
+    'ScatterFitOptions',
+    'ScatterSummarizationStrategy',
+    'ScatterSummarizationStrategyVisitor',
+    'SelectIndexFrom1dEnumArraySeries',
+    'SelectIndexFrom1dNumericArraySeries',
+    'SelectValue',
+    'SelectValueVisitor',
+    'Series',
+    'SeriesVisitor',
+    'SeriesCrossoverRanges',
+    'SeriesEqualityRanges',
+    'SeriesName',
+    'SeriesSpec',
+    'SetNegativeValuesToZero',
+    'SignalFilterConfiguration',
+    'SignalFilterConfigurationVisitor',
+    'SignalFilterSeries',
+    'SpatialDecimateStrategy',
+    'StabilityDetectionRanges',
+    'StabilityWindowConfiguration',
+    'StaleRanges',
+    'StandardDeviation',
+    'StringConstant',
+    'StringConstantVisitor',
+    'StringSetConstant',
+    'StringSetConstantVisitor',
+    'Sum',
+    'SumSeries',
+    'SummarizationStrategy',
+    'SummarizationStrategyVisitor',
+    'SummarizeCartesian',
+    'SummarizeCartesian3d',
+    'SummarizeGeo',
+    'SummarizeRanges',
+    'SummarizeSeries',
+    'TagFilter',
+    'TagFilterOperator',
+    'TagFilterValidationErrorType',
+    'TagFilters',
+    'TagFiltersVisitor',
+    'Threshold',
+    'ThresholdVisitor',
+    'ThresholdOperator',
+    'ThresholdingRanges',
+    'TimeBucketedGeoPlot',
+    'TimeDifferenceSeries',
+    'TimeSeriesCurveFit',
+    'TimeSeriesFitOptions',
+    'TimestampAndId',
+    'TimestampConstant',
+    'TimestampConstantVisitor',
+    'UnaryArithmeticOperation',
+    'UnaryArithmeticSeries',
+    'UnionRanges',
+    'UnitComputationError',
+    'UnitComputationErrorVisitor',
+    'UnitConversionSeries',
+    'UnitOperation',
+    'UnitResult',
+    'UnitResultVisitor',
+    'UnitsMissing',
+    'ValueDifferenceSeries',
+    'ValueMapSeries',
+    'VariableName',
+    'VariableValue',
+    'VariableValueVisitor',
+    'Window',
+    'WindowVisitor',
+    'ComputeService',
+]
+
