@@ -10,7 +10,6 @@ from .._impl import (
     scout_datareview_api_AutomaticCheckEvaluationReviewActionLog as AutomaticCheckEvaluationReviewActionLog,
     scout_datareview_api_AutomaticCheckEvaluationReviewActionLogEntry as AutomaticCheckEvaluationReviewActionLogEntry,
     scout_datareview_api_AutomaticCheckEvaluationReviewActionVisitor as AutomaticCheckEvaluationReviewActionVisitor,
-    scout_datareview_api_AutomaticCheckEvaluationRid as AutomaticCheckEvaluationRid,
     scout_datareview_api_AutomaticCheckEvaluationState as AutomaticCheckEvaluationState,
     scout_datareview_api_AutomaticCheckEvaluationStateVisitor as AutomaticCheckEvaluationStateVisitor,
     scout_datareview_api_AutomaticCheckExecutionFailedToRun as AutomaticCheckExecutionFailedToRun,
@@ -107,3 +106,110 @@ from .._impl import (
     scout_datareview_api_UpdateNotes as UpdateNotes,
 )
 
+__all__ = [
+    'ArchiveDataReview',
+    'AutomaticCheckEvaluation',
+    'AutomaticCheckEvaluationAction',
+    'AutomaticCheckEvaluationActionVisitor',
+    'AutomaticCheckEvaluationActionLog',
+    'AutomaticCheckEvaluationActionLogEntry',
+    'AutomaticCheckEvaluationReviewAction',
+    'AutomaticCheckEvaluationReviewActionVisitor',
+    'AutomaticCheckEvaluationReviewActionLog',
+    'AutomaticCheckEvaluationReviewActionLogEntry',
+    'AutomaticCheckEvaluationState',
+    'AutomaticCheckEvaluationStateVisitor',
+    'AutomaticCheckExecutionFailedToRun',
+    'AutomaticCheckExecutionFinished',
+    'AutomaticCheckExecutionStarted',
+    'BatchAutomaticCheckEvaluationActionRequest',
+    'BatchAutomaticCheckEvaluationActionResponse',
+    'BatchCheckAlertActionRequest',
+    'BatchCheckAlertActionResponse',
+    'BatchInitiateDataReviewRequest',
+    'BatchInitiateDataReviewResponse',
+    'BatchManualCheckEvaluationActionRequest',
+    'CheckAlert',
+    'CheckAlertAction',
+    'CheckAlertActionVisitor',
+    'CheckAlertActionLog',
+    'CheckAlertActionLogEntry',
+    'CheckAlertStatus',
+    'CheckAlertsHistogramBuckets',
+    'CheckAlertsHistogramBucketsVisitor',
+    'CheckAlertsHistogramRequest',
+    'CheckAlertsHistogramResponse',
+    'CheckAlertsPriorityHistogram',
+    'CheckAlertsStatusHistogram',
+    'CheckAlertsUnstackedHistogram',
+    'CheckEvaluation',
+    'CheckEvaluationVisitor',
+    'ChecklistEvaluation',
+    'CloseAction',
+    'CloseActionVisitor',
+    'CloseAllLinkedAlerts',
+    'CloseAndDetachFromNotebook',
+    'CloseAndDuplicatePreviouslyLinkedNotebook',
+    'CloseAndLinkToNotebook',
+    'CloseStrategy',
+    'CloseStrategyVisitor',
+    'CloseWithFurtherAction',
+    'CloseWithIgnoreAlert',
+    'ClosedWithFurtherActionState',
+    'CreateDataReviewRequest',
+    'DataReview',
+    'DataReviewPage',
+    'DuplicateAndLinkNotebook',
+    'ExecutingState',
+    'ExecutionRetriggered',
+    'FailedToExecuteState',
+    'FindDataReviewsRequest',
+    'GeneratedAlertsState',
+    'HistogramBucket',
+    'HistogramDistributionVariable',
+    'HistogramDistributionVariableVisitor',
+    'HistogramEndTimeVariable',
+    'HistogramPriorityBucket',
+    'HistogramPriorityVariable',
+    'HistogramStartTimeVariable',
+    'HistogramStatusBucket',
+    'HistogramStatusVariable',
+    'HistogramSubGroupVariable',
+    'HistogramSubGroupVariableVisitor',
+    'LinkNotebook',
+    'LinkNotebookStrategy',
+    'LinkNotebookStrategyVisitor',
+    'ManualCheckAlertAction',
+    'ManualCheckAlertActionVisitor',
+    'ManualCheckEvaluation',
+    'ManualCheckEvaluationActionLog',
+    'ManualCheckEvaluationActionLogEntry',
+    'ManualCheckEvaluationRid',
+    'ManualCheckEvaluationState',
+    'ManualCheckEvaluationStateVisitor',
+    'Pass',
+    'PassState',
+    'PassingExecutionState',
+    'PendingExecutionState',
+    'PendingReviewState',
+    'Reassign',
+    'Reopen',
+    'ReopenAllLinkedAlerts',
+    'ReopenAndDetachFromNotebook',
+    'ReopenAndDuplicatePreviouslyLinkedNotebook',
+    'ReopenAndLinkToNotebook',
+    'ReopenStrategy',
+    'ReopenStrategyVisitor',
+    'RerunFailedAutomaticChecksRequest',
+    'SearchCheckAlertsRequest',
+    'SearchCheckAlertsResponse',
+    'SearchCheckAlertsSortField',
+    'SearchCheckAlertsSortOptions',
+    'Status',
+    'TooManyAlertsState',
+    'UnarchiveDataReview',
+    'UnlinkNotebook',
+    'UpdateNotes',
+    'DataReviewService',
+]
+
