@@ -60,3 +60,64 @@ from .._impl import (
     scout_datasource_connection_api_VisualCrossingType as VisualCrossingType,
 )
 
+__all__ = [
+    'BigQueryChannelNameComponent',
+    'BigQueryConnectionDetails',
+    'BigQueryScrapingConfig',
+    'BucketName',
+    'ColumnName',
+    'Connection',
+    'ConnectionDetails',
+    'ConnectionDetailsVisitor',
+    'ConnectionPlottingConfiguration',
+    'ConnectionRid',
+    'ConnectionStatus',
+    'CreateConnection',
+    'DatasetName',
+    'Duration',
+    'HeaderValue',
+    'HeaderValueVisitor',
+    'Influx1ConnectionDetails',
+    'Influx2ConnectionDetails',
+    'InfluxChannelNameComponent',
+    'InfluxChannelNameComponentVisitor',
+    'InfluxScrapingConfig',
+    'InfluxScrapingFilter',
+    'InfluxScrapingFilterVisitor',
+    'InfluxSeriesArchetypeConstructionConfig',
+    'LimitsConfig',
+    'LocationName',
+    'MeasurementName',
+    'NominalChannelNameComponent',
+    'NominalChannelNameComponentVisitor',
+    'NominalConnectionDetails',
+    'NominalScrapingConfig',
+    'PasswordCredentials',
+    'PivotedTimescaleChannelNameComponent',
+    'PivotedTimescaleChannelNameComponentVisitor',
+    'PivotedTimescaleScrapingConfig',
+    'PopulateSeriesRequest',
+    'ProjectName',
+    'SchemaName',
+    'ScrapingConfig',
+    'ScrapingConfigVisitor',
+    'SecretName',
+    'SecretRid',
+    'TableName',
+    'TemporalUnit',
+    'TimescaleConnectionDetails',
+    'TimescaleScrapingFilter',
+    'TimescaleScrapingFilterVisitor',
+    'TimestreamChannelNameComponent',
+    'TimestreamChannelNameComponentVisitor',
+    'TimestreamConnectionDetails',
+    'TimestreamScrapingConfig',
+    'TimestreamScrapingFilter',
+    'TimestreamScrapingFilterVisitor',
+    'UpdateConnectionRequest',
+    'VisualCrossingAvailableSeries',
+    'VisualCrossingConnectionDetails',
+    'VisualCrossingScrapingConfig',
+    'VisualCrossingType',
+]
+
