@@ -1,6 +1,7 @@
 # coding=utf-8
 from .._impl import (
     scout_rids_api_ApiKeyRid as ApiKeyRid,
+    scout_rids_api_AssetRefName as AssetRefName,
     scout_rids_api_AssetRid as AssetRid,
     scout_rids_api_CheckAlertRid as CheckAlertRid,
     scout_rids_api_CheckAlertState as CheckAlertState,
@@ -24,3 +25,29 @@ from .._impl import (
     scout_rids_api_VizId as VizId,
 )
 
+__all__ = [
+    'ApiKeyRid',
+    'AssetRefName',
+    'AssetRid',
+    'CheckAlertRid',
+    'CheckAlertState',
+    'CheckAlertStateVisitor',
+    'CheckLineageRid',
+    'CheckRid',
+    'ChecklistRid',
+    'ClosedWithFurtherActionAlertState',
+    'ClosedWithIgnoreAlertState',
+    'DataReviewRid',
+    'FunctionLineageRid',
+    'FunctionRid',
+    'NotebookRid',
+    'PendingReviewAlertState',
+    'SnapshotRid',
+    'TemplateRid',
+    'TypeRid',
+    'UserRid',
+    'Version',
+    'VersionedVizId',
+    'VizId',
+]
+
